/***************************************************************************
                          cblastaln.h  -  description
                             -------------------
    begin                : Thu Nov 21 2002
    copyright            : (C) 2002 by Oleksiy Kohany
    email                : kohany@girinst.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CBLASTALN_H
#define CBLASTALN_H

#include <string>
#include <iostream>
#include <stdexcept>
#include "BioAlignment.h"
#include "constants.h"
#include "chspinfo.h"

using namespace std;
namespace bio {
/**
  *@author Oleksiy Kohany
  */

class CBlastAln : public BioAlignment, CHSPInfo
{
public:
	static const short BY_SCORE = 0;
	static const short BY_EXPECTATION = 1;
	short evaluateBy;
    CBlastAln();
    ~CBlastAln();
    /** Reads one HSP from blast output, and assigns it to CBlastAln& object */
    static int read(CBlastAln& aln, istream& is);
    /** Reads one HSP from blast output, and assigns it to CBlastAln& object */
    static int read(CBlastAln& aln, FILE* is);
    /** Forwards read pointer to the begining of next HSP */
    bool readHSPHead(istream& is);
    /** Forwards read pointer to the begining of next HSP */
    bool readHSPHead(FILE* is);
    /** Reads one HSP (high scoring pair) from blast output file. Information about query name and database sequence name is stored in static member variables. */
    int read(istream& is);
    /** Reads one HSP (high scoring pair) from blast output file. Information about query name and database sequence name is stored in static member variables. */
    int read(FILE* is);
    /** No descriptions */
    ostream& printAln(ostream &os) ;
    /** No descriptions */
    void printMap(ostream &os) const;
    /** No descriptions */
    void printMap_db1(ostream &os) const;
    /** No descriptions */
    void printMap_db2(ostream &os) const;
    /** No descriptions */
    virtual double calcSim() const;
    /** No descriptions */
    static char* cleanComa(char *ptr);
    void setEvaluateBy(short type);
protected: // Protected attributes
    /**  */
    static char sQUName[MAXNAMESIZE];
    /**  */
    static char sDBName[MAXNAMESIZE];
    /**  */
    static char sReadBuf[MAXLINELENGTH];
    static unsigned int iDBLen, iQULen;
};

istream& operator >> (istream& is, CBlastAln& aln);
}
#endif
